@@ -8,7 +8,7 @@ use crate::{
 };
 use anyhow::Result;
 use bytes::Bytes;
-use cross_krb5::{K5Ctx, ServerCtx};
+use cross_krb5::{AcceptFlags, K5Ctx, ServerCtx};
 use fxhash::FxBuildHasher;
 use parking_lot::RwLock;
 use rand::Rng;
@@ -75,7 +75,8 @@ impl SecStore {
         tok: &[u8],
     ) -> Result<(K5CtxWrap<ServerCtx>, u128, Bytes)> {
         let spn = Some(self.spn.as_str());
-        let (ctx, tok) = task::block_in_place(|| ServerCtx::accept(spn, tok))?;
+        let (ctx, tok) =
+            task::block_in_place(|| ServerCtx::accept(AcceptFlags::empty(), spn, tok))?;
         let secret = rand::thread_rng().gen::<u128>();
         Ok((K5CtxWrap::new(ctx), secret, utils::bytes(&*tok)))
     }
