@@ -18,7 +18,7 @@ use crate::{
 };
 use anyhow::{anyhow, Error, Result};
 use bytes::{Buf, BufMut, Bytes};
-use cross_krb5::ClientCtx;
+use cross_krb5::{ClientCtx, InitiateFlags};
 use futures::{
     channel::{
         mpsc::{self, Receiver, Sender, UnboundedReceiver, UnboundedSender},
@@ -1289,7 +1289,9 @@ async fn hello_publisher(
         }
         Auth::Krb5 { upn, .. } => {
             let p = upn.as_ref().map(|p| p.as_str());
-            let (ctx, tok) = task::block_in_place(|| ClientCtx::initiate(p, target_spn))?;
+            let (ctx, tok) = task::block_in_place(|| {
+                ClientCtx::initiate(InitiateFlags::empty(), p, target_spn)
+            })?;
             con.send_one(&Hello::Token(utils::bytes(&*tok))).await?;
             match con.receive().await? {
                 Hello::Anonymous => bail!("publisher failed mutual authentication"),
